@@ -3,9 +3,7 @@ from __future__ import annotations
 import argparse
 import itertools
 
-from tabulate import tabulate
-
-from lazyfpl import conf, fetch, helpers
+from lazyfpl import fetch, helpers
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
@@ -25,7 +23,7 @@ if __name__ == "__main__":
 
     players = sorted(
         fetch.players(),
-        key=lambda x: (x.position, x.xP or 0),
+        key=lambda x: (helpers.position_order(x.position), x.xP or 0),
         reverse=True,
     )
 
@@ -38,7 +36,7 @@ if __name__ == "__main__":
                 list(p)[: args.top]
                 for _, p in itertools.groupby(
                     players,
-                    key=lambda x: x.position,
+                    key=lambda x: helpers.position_order(x.position),
                 )
             ]
         )
@@ -46,9 +44,7 @@ if __name__ == "__main__":
     bis = helpers.best_lineup(players)
 
     print(
-        tabulate(
-            [{"BIS": "X" if p in bis else ""} | p.display() for p in players],
-            tablefmt=conf.tabulate_format,
-            headers={},
+        helpers.tabulater(
+            [dict({"BIS": "X" if p in bis else ""} | p.display()) for p in players],
         ),
     )
